@@ -13,14 +13,12 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Tests for SchoolTool calendaring views.
 """
 
-import sys
 import unittest
 import doctest
 from pprint import pprint
@@ -458,20 +456,13 @@ def pdfTearDown(test=None):
 
 
 def test_suite():
-    from schooltool.app.tests.test_pdf import tryToSetUpReportLab
     suite = unittest.TestSuite()
     suite.addTest(doctest.DocTestSuite('schooltool.app.browser.pdfcal'))
-    success = tryToSetUpReportLab()
-    if success:
-        optionflags = (doctest.ELLIPSIS | doctest.REPORT_NDIFF
-                       | doctest.NORMALIZE_WHITESPACE)
-        docsuite = doctest.DocTestSuite(setUp=pdfSetUp, tearDown=pdfTearDown,
-                                        optionflags=optionflags)
-        suite.addTest(docsuite)
-    else:
-        print >> sys.stderr, ("reportlab or TrueType fonts not found;"
-                              " PDF generator tests skipped")
-
+    optionflags = (doctest.ELLIPSIS | doctest.REPORT_NDIFF
+                   | doctest.NORMALIZE_WHITESPACE)
+    docsuite = doctest.DocTestSuite(setUp=pdfSetUp, tearDown=pdfTearDown,
+                                    optionflags=optionflags)
+    suite.addTest(docsuite)
     return suite
 
 
