@@ -1,4 +1,4 @@
-# Make a package.
+import stesting
 
 def registerTestSetup():
     from zope.interface import classImplements
