@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Functional tests for schooltool.export
@@ -24,7 +23,11 @@ import unittest
 from schooltool.testing.functional import collect_ftests
 from schooltool.export.ftesting import export_functional_layer
 
+
 def test_suite():
+    """
+    use "--at-level 2" or "make testall" to reach these tests
+    """
     return collect_ftests(layer=export_functional_layer, level=2)
 
 
