@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """Tests for Pluggable Traversers
 """
@@ -23,13 +22,27 @@ import doctest
 
 from zope.component import testing
 
+from schooltool.testing.setup import ZCMLWrapper
+
+
+def setUp(test=None):
+    testing.setUp(test=test)
+    zcml = ZCMLWrapper()
+    zcml.include('schooltool.common', file="zcmlfiles.zcml")
+    zcml.include('schooltool.traverser', file='meta.zcml')
+    zcml.include('schooltool.traverser')
+    test.globs['zcml'] = zcml
 
 def test_suite():
+    optionflags = (doctest.NORMALIZE_WHITESPACE |
+                   doctest.ELLIPSIS |
+                   doctest.REPORT_NDIFF)
+
     return unittest.TestSuite((
         doctest.DocFileSuite(
             'README.txt',
-            setUp=testing.setUp, tearDown=testing.tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS),
+            setUp=setUp, tearDown=testing.tearDown,
+            optionflags=optionflags),
         ))
 
 if __name__ == '__main__':
